from ..grpc_gen import status_pb2
from ..grpc_gen.milvus_pb2 import TopKQueryResult as Grpc_Result
from ..client.abstract import TopKQueryResult
from ..client.exceptions import ParamError


def merge_results(results_list, topk, *args, **kwargs):
    """
    merge query results
    """

    def _reduce(source_ids, ids, source_diss, diss, k, reverse):
        """

        """
        if source_diss[k - 1] <= diss[0]:
            return source_ids, source_diss
        if diss[k - 1] <= source_diss[0]:
            return ids, diss

        source_diss.extend(diss)
        diss_t = enumerate(source_diss)
        diss_m_rst = sorted(diss_t, key=lambda x: x[1], reverse=reverse)[:k]
        diss_m_out = [id_ for _, id_ in diss_m_rst]

        source_ids.extend(ids)
        id_m_out = [source_ids[i] for i, _ in diss_m_rst]

        return id_m_out, diss_m_out

    status = status_pb2.Status(error_code=status_pb2.SUCCESS,
                               reason="Success")

    reverse = kwargs.get('reverse', False)
    raw = kwargs.get('raw', False)

    if not results_list:
        return status, [], []

    merge_id_results = []
    merge_dis_results = []
    row_num = 0

    for files_collection in results_list:
        if not isinstance(files_collection, Grpc_Result) and \
                not isinstance(files_collection, TopKQueryResult):
            return ParamError("Result type is unknown.")

        row_num = files_collection.row_num
        if not row_num:
            continue

        ids = files_collection.ids
        diss = files_collection.distances  # distance collections
        # Notice: batch_len is equal to topk, may need to compare with topk
        batch_len = len(ids) // row_num

        for row_index in range(row_num):
            id_batch = ids[row_index * batch_len: (row_index + 1) * batch_len]
            dis_batch = diss[row_index * batch_len: (row_index + 1) * batch_len]

            if len(merge_id_results) < row_index:
                raise ValueError("merge error")
            if len(merge_id_results) == row_index:
                merge_id_results.append(id_batch)
                merge_dis_results.append(dis_batch)
            else:
                merge_id_results[row_index], merge_dis_results[row_index] = \
                    _reduce(merge_id_results[row_index], id_batch,
                            merge_dis_results[row_index], dis_batch,
                            batch_len,
                            reverse)

    id_mrege_list = []
    dis_mrege_list = []

    for id_results, dis_results in zip(merge_id_results, merge_dis_results):
        id_mrege_list.extend(id_results)
        dis_mrege_list.extend(dis_results)

    raw_result = Grpc_Result(
        status=status,
        row_num=row_num,
        ids=id_mrege_list,
        distances=dis_mrege_list
    )

    return raw_result if raw else TopKQueryResult(raw_result)



from enum import IntEnum


class Status:
    """
    :attribute code: int (optional) default as ok

    :attribute message: str (optional) current status message
    """

    SUCCESS = 0
    UNEXPECTED_ERROR = 1
    CONNECT_FAILED = 2
    PERMISSION_DENIED = 3
    TABLE_NOT_EXISTS = 4
    ILLEGAL_ARGUMENT = 5
    ILLEGAL_RANGE = 6
    ILLEGAL_DIMENSION = 7
    ILLEGAL_INDEX_TYPE = 8
    ILLEGAL_TABLE_NAME = 9
    ILLEGAL_TOPK = 10
    ILLEGAL_ROWRECORD = 11
    ILLEGAL_VECTOR_ID = 12
    ILLEGAL_SEARCH_RESULT = 13
    FILE_NOT_FOUND = 14
    META_FAILED = 15
    CACHE_FAILED = 16
    CANNOT_CREATE_FOLDER = 17
    CANNOT_CREATE_FILE = 18
    CANNOT_DELETE_FOLDER = 19
    CANNOT_DELETE_FILE = 20
    BUILD_INDEX_ERROR = 21
    ILLEGAL_NLIST = 22
    ILLEGAL_METRIC_TYPE = 23
    OUT_OF_MEMORY = 24

    def __init__(self, code=SUCCESS, message="Success"):
        self.code = code
        self.message = message

    def __repr__(self):
        attr_list = ['%s=%r' % (key, value)
                     for key, value in self.__dict__.items()]
        return '%s(%s)' % (self.__class__.__name__, ', '.join(attr_list))

    def __eq__(self, other):
        """
        Make Status comparable with self by code
        """
        if isinstance(other, int):
            return self.code == other

        return isinstance(other, self.__class__) and self.code == other.code

    def __ne__(self, other):
        return self != other

    def OK(self):
        return self.code == Status.SUCCESS


class IndexType(IntEnum):
    INVALID = 0
    FLAT = 1
    IVFLAT = 2
    IVF_SQ8 = 3
    RNSG = 4
    IVF_SQ8H = 5
    IVF_PQ = 6
    HNSW = 11

    # alternative name
    IVF_FLAT = IVFLAT
    IVF_SQ8_H = IVF_SQ8H

    def __repr__(self):
        return "<{}: {}>".format(self.__class__.__name__, self._name_)

    def __str__(self):
        return self._name_


class MetricType(IntEnum):
    INVALID = 0
    L2 = 1
    IP = 2
    # Only supported for byte vectors
    HAMMING = 3
    JACCARD = 4
    TANIMOTO = 5
    #
    SUBSTRUCTURE = 6
    SUPERSTRUCTURE = 7

    def __repr__(self):
        return "<{}: {}>".format(self.__class__.__name__, self._name_)

    def __str__(self):
        return self._name_



from urllib.parse import urlparse
import logging

import grpc
from grpc._cython import cygrpc

from ..grpc_gen import milvus_pb2_grpc
from ..grpc_gen import milvus_pb2 as grpc_types
from .abstract import ConnectIntf, CollectionSchema, IndexParam, PartitionParam, TopKQueryResult, TableInfo
from .prepare import Prepare
from .types import MetricType, Status
from .check import (
    int_or_str,
    is_legal_host,
    is_legal_port,
)

from .hooks import BaseSearchHook
from .client_hooks import SearchHook
from .exceptions import ParamError, NotConnectError
from ..settings import DefaultConfig as config
from . import __version__

LOGGER = logging.getLogger(__name__)


class GrpcHandler(ConnectIntf):
    def __init__(self, host=None, port=None, **kwargs):
        self._channel = None
        self._stub = None
        self._uri = None
        self.status = None

        # client hook
        self._search_hook = SearchHook()
        self._search_file_hook = SearchHook()

        # set server uri if object is initialized with parameter
        _uri = kwargs.get("uri", None)
        self._uri = (host or port or _uri) and self._set_uri(host, port, uri=_uri)

    def __str__(self):
        attr_list = ['%s=%r' % (key, value)
                     for key, value in self.__dict__.items() if not key.startswith('_')]
        return '<Milvus: {}>'.format(', '.join(attr_list))

    def __enter__(self):
        self._setup()

        return self

    def __exit__(self, exc_type, exc_val, exc_tb):
        del self._channel
        del self._stub

    def _setup(self):
        """
        Create a grpc channel and a stub

        :raises: NotConnectError

        """

        if not self._channel:
            self._set_channel()

        try:
            # check if server is ready
            grpc.channel_ready_future(self._channel).result(timeout=1)
        except grpc.FutureTimeoutError:
            del self._channel
            raise NotConnectError('Fail connecting to server on {}. Timeout'.format(self._uri))
        except grpc.RpcError as e:
            del self._channel
            raise NotConnectError("Connect error: <{}>".format(e))
        # Unexpected error
        except Exception as e:
            raise NotConnectError("Error occurred when trying to connect server:\n"
                                  "\t<{}>".format(str(e)))

        self._stub = milvus_pb2_grpc.MilvusServiceStub(self._channel)
        self.status = Status()

    def _set_uri(self, host, port, **kwargs):
        """
        Set server network address

        :raises: ParamError

        """
        if host is not None:
            _port = port if port is not None else config.GRPC_PORT
            _host = host
        elif port is None:
            try:
                _uri = kwargs.get("uri", None)
                # Ignore uri check here
                # if not is_legal_uri(_uri):
                #     raise ParamError("uri {} is illegal".format(_uri))
                #
                # If uri is empty (None or '') use default uri instead
                # (the behavior may change in the future)
                # _uri = urlparse(_uri) if _uri is not None else urlparse(config.GRPC_URI)
                _uri = urlparse(_uri) if _uri else urlparse(config.GRPC_URI)
                _host = _uri.hostname
                _port = _uri.port
            except (AttributeError, ValueError, TypeError) as e:
                raise ParamError("uri is illegal: {}".format(e))
        else:
            raise ParamError("Param is not complete. Please invoke as follow:\n"
                             "\t(host = ${HOST}, port = ${PORT})\n"
                             "\t(uri = ${URI})\n")

        if not is_legal_host(_host) or not is_legal_port(_port):
            raise ParamError("host or port is illeagl")

        return "{}:{}".format(str(_host), str(_port))

    def _set_channel(self):
        """
        Set grpc channel. Use default server uri if uri is not set.
        """
        if self._channel:
            del self._channel

        # set transport unlimited
        self._channel = grpc.insecure_channel(
            self._uri,
            # self._uri or config.GRPC_ADDRESS,
            options=[(cygrpc.ChannelArgKey.max_send_message_length, -1),
                     (cygrpc.ChannelArgKey.max_receive_message_length, -1)]
        )

    def set_hook(self, **kwargs):
        """
        specify client hooks.
        The client hooks are used in methods which interact with server.
        Use key-value method to set hooks. Supported hook setting currently is as follow.

            search hook,
            search-in-file hook

        """

        # config search hook
        _search_hook = kwargs.get('search', None)
        if _search_hook:
            if not isinstance(_search_hook, BaseSearchHook):
                raise ParamError("search hook must be a subclass of `BaseSearchHook`")

            self._search_hook = _search_hook

        _search_file_hook = kwargs.get('search_in_file', None)
        if _search_file_hook:
            if not isinstance(_search_file_hook, BaseSearchHook):
                raise ParamError("search hook must be a subclass of `BaseSearchHook`")

            self._search_file_hook = _search_file_hook

    @property
    def server_address(self):
        """
        Server network address
        """
        return self._uri

    def connect(self, host=None, port=None, uri=None, timeout=1):

        """
        Connect method should be called before any operations.
        Server will be connected after connect return OK

        :type  host: str
        :type  port: str
        :type  uri: str
        :type  timeout: float
        :param host: (Optional) host of the server, default host is 127.0.0.1
        :param port: (Optional) port of the server, default port is 19530
        :param uri: (Optional) only support tcp proto now, default uri is

                `tcp://127.0.0.1:19530`

        :param timeout: (Optional) connection timeout, default timeout is 3000ms

        :return: Status, indicate if connect is successful
        :rtype: Status
        
        :raises: NotConnectError
        """
        if self.connected():
            return Status(message="You have already connected {} !".format(self._uri),
                          code=Status.CONNECT_FAILED)

        # TODO: Here may cause bug: IF user has already connected a server but server is down,
        # client may connect to a new server. It's a undesirable behavior.

        if (host or port or uri) or not self._uri:
            # if self._uri and self._uri != self._set_uri(host, port, uri=uri):
            #     return Status(message="The server address is set as {}, "
            #                           "you cannot connect other server".format(self._uri),
            #                   code=Status.CONNECT_FAILED)
            self._uri = self._set_uri(host, port, uri=uri)

        if self._channel:
            del self._channel
            self._channel = None

        self._set_channel()

        try:
            # check if server is ready
            grpc.channel_ready_future(self._channel).result(timeout=timeout)
        except grpc.FutureTimeoutError:
            del self._channel
            self._channel = None
            raise NotConnectError('Fail connecting to server on {}. Timeout'.format(self._uri))
        except grpc.RpcError as e:
            del self._channel
            self._channel = None
            raise NotConnectError("Connect error: <{}>".format(e))
        # Unexpected error
        except Exception as e:
            raise NotConnectError("Error occurred when trying to connect server:\n"
                                  "\t<{}>".format(str(e)))

        self._stub = milvus_pb2_grpc.MilvusServiceStub(self._channel)
        self.status = Status()
        return self.status

    def connected(self):
        """
        Check if client is connected to the server

        :return: if client is connected
        :rtype: bool
        """
        if not self._stub or not self._channel:
            return False
        try:
            grpc.channel_ready_future(self._channel).result(timeout=2)
            return True
        except (grpc.FutureTimeoutError, grpc.RpcError):
            return False

    def disconnect(self):
        """
        Disconnect with the server and distroy the channel

        :return: Status, indicate if disconnect is successful
        :rtype: Status
        """
        # After closeing, a exception stack trace is printed from a background thread and
        # no exception is thrown in the main thread, issue is under test and not done yet
        # checkout https://github.com/grpc/grpc/issues/18995
        # Also checkout Properly Specify Channel.close Behavior in Python:
        # https://github.com/grpc/grpc/issues/19235
        if not self.connected():
            raise NotConnectError('Please connect to the server first!')

        # closing channel by calling interface close() will result in grpc interval error
        del self._channel

        # try:
        #     self._channel.close()
        # except Exception as e:
        #     LOGGER.error(e)
        #     return Status(code=Status.CONNECT_FAILED, message='Disconnection failed')

        self.status = None
        self._channel = None
        self._stub = None

        return Status(message='Disconnect successfully')

    def server_version(self, timeout=10):
        """
        Provide server version

        :return:
            Status: indicate if operation is successful

            str : Server version

        :rtype: (Status, str)
        """
        return self._cmd(cmd='version', timeout=timeout)

    def server_status(self, timeout=10):
        """
        Provide server status

        :return:
            Status: indicate if operation is successful

            str : Server version

        :rtype: (Status, str)
        """
        return self._cmd(cmd='status', timeout=timeout)

    def _cmd(self, cmd, timeout=10):
        cmd = Prepare.cmd(cmd)
        try:
            response = self._stub.Cmd.future(cmd).result(timeout=timeout)
            if response.status.error_code == 0:
                return Status(message='Success!'), response.string_reply

            return Status(code=response.status.error_code, message=response.status.reason), None
        except grpc.FutureTimeoutError as e:
            LOGGER.error(e)
            return Status(Status.UNEXPECTED_ERROR, message='Request timeout'), None
        except grpc.RpcError as e:
            LOGGER.error(e)
            return Status(e.code(), message='Error occurred. {}'.format(e.details())), None

    def create_table(self, table_name, dimension, index_file_size, metric_type, param, timeout=10):
        """
        Create table

        :type  param: dict or TableSchema
        :param param: Provide table information to be created

                `example param={'table_name': 'name',
                                'dimension': 16,
                                'index_file_size': 1024 (default)，
                                'metric_type': Metric_type.L2 (default)
                                }`

                `OR using Prepare.table_schema to create param`

        :param timeout: timeout, The unit is seconds
        :type  timeout: double

        :return: Status, indicate if operation is successful
        :rtype: Status
        """

        table_schema = Prepare.table_schema(table_name, dimension, index_file_size, metric_type, param)

        try:
            status = self._stub.CreateTable.future(table_schema).result(timeout=timeout)
            if status.error_code == 0:
                return Status(message='Create collection successfully!')

            LOGGER.error(status)
            return Status(code=status.error_code, message=status.reason)
        except grpc.FutureTimeoutError as e:
            LOGGER.error(e)
            return Status(Status.UNEXPECTED_ERROR, message='Request timeout')
        except grpc.RpcError as e:
            LOGGER.error(e)
            return Status(e.code(), message='Error occurred: {}'.format(e.details()))

    def has_table(self, table_name, timeout=10):
        """

        This method is used to test table existence.

        :param table_name: table name is going to be tested.
        :type  table_name: str
        :param timeout: time waiting for server response
        :type  timeout: int

        :return:
            Status: indicate if vectors inserted successfully
            bool if given table_name exists

        """

        table_name = Prepare.table_name(table_name)

        try:
            reply = self._stub.HasTable.future(table_name).result(timeout=timeout)
            if reply.status.error_code == 0:
                return Status(), reply.bool_reply

            return Status(code=reply.status.error_code,
                          message=reply.status.reason), False
        except grpc.FutureTimeoutError as e:
            LOGGER.error(e)
            return Status(code=Status.UNEXPECTED_ERROR, message="request timeout"), False
        except grpc.RpcError as e:
            LOGGER.error(e)
            return Status(code=e.code(), message=e.details()), False

    def describe_table(self, table_name, timeout=10):
        """
        Show table information

        :type  table_name: str
        :param table_name: which table to be shown

        :returns: (Status, table_schema)
            Status: indicate if query is successful
            table_schema: return when operation is successful
        :rtype: (Status, TableSchema)
        """

        table_name = Prepare.table_name(table_name)

        try:
            response = self._stub.DescribeTable.future(table_name).result(timeout=timeout)

            if response.status.error_code == 0:
                table = CollectionSchema(
                    collection_name=response.table_name,
                    dimension=response.dimension,
                    index_file_size=response.index_file_size,
                    metric_type=MetricType(response.metric_type)
                )

                return Status(message='Describe table successfully!'), table

            LOGGER.error(response.status)
            return Status(code=response.status.error_code, message=response.status.reason), None

        except grpc.FutureTimeoutError as e:
            LOGGER.error(e)
            return Status(Status.UNEXPECTED_ERROR, message='Request timeout'), None
        except grpc.RpcError as e:
            LOGGER.error(e)
            return Status(e.code(), message='Error occurred. {}'.format(e.details())), None

    def count_table(self, table_name, timeout=30):
        """
        obtain vector number in table

        :type  table_name: str
        :param table_name: target table name.

        :returns:
            Status: indicate if operation is successful

            res: int, table row count
        """

        table_name = Prepare.table_name(table_name)

        try:
            response = self._stub.CountTable.future(table_name).result(timeout=timeout)
            if response.status.error_code == 0:
                return Status(message='Success!'), response.table_row_count

            return Status(code=response.status.error_code, message=response.status.reason), None
        except grpc.FutureTimeoutError as e:
            LOGGER.error(e)
            return Status(Status.UNEXPECTED_ERROR, message='Request timeout'), None
        except grpc.RpcError as e:
            LOGGER.error(e)
            return Status(e.code(), message='Error occurred. {}'.format(e.details())), None

    def show_tables(self, timeout=10):
        """
        Show all tables information in database

        :return:
            Status: indicate if this operation is successful

            tables: list of table names, return when operation
                    is successful
        :rtype:
            (Status, list[str])
        """

        cmd = Prepare.cmd('show_tables')
        try:
            response = self._stub.ShowTables.future(cmd).result(timeout=timeout)
            if response.status.error_code == 0:
                return Status(message='Show tables successfully!'), \
                       [name for name in response.table_names if len(name) > 0]
            return Status(response.status.error_code, message=response.status.reason), []
        except grpc.FutureTimeoutError:
            return Status(Status.UNEXPECTED_ERROR, message="Request timeout"), []
        except grpc.RpcError as e:
            LOGGER.error(e)
            return Status(e.code(), message='Error occurred. {}'.format(e.details())), []

    def show_table_info(self, table_name, timeout=10):
        request = grpc_types.TableName(table_name=table_name)

        try:
            response = self._stub.ShowTableInfo.future(request).result(timeout=timeout)
            rpc_status = response.status

            if rpc_status.error_code == 0:
                return Status(), TableInfo(response)

            return Status(rpc_status.error_code, rpc_status.reason), None
        except grpc.FutureTimeoutError:
            return Status(Status.UNEXPECTED_ERROR, message="Request timeout"), None
        except grpc.RpcError as e:
            return Status(Status.UNEXPECTED_ERROR, e.details()), None

    def preload_table(self, table_name, timeout=None):
        """
        Load table to cache in advance

        :type table_name: str
        :param table_name: table to preload

        :returns:
            Status:  indicate if invoke is successful
        """

        table_name = Prepare.table_name(table_name)

        try:
            status = self._stub.PreloadTable.future(table_name).result(timeout=timeout)
            return Status(code=status.error_code, message=status.reason)
        except grpc.FutureTimeoutError as e:
            LOGGER.error(e)
            return Status(Status.UNEXPECTED_ERROR, message='Request timeout')
        except grpc.RpcError as e:
            return Status(code=e.code(), message='Error occurred. {}'.format(e.details()))

    def drop_table(self, table_name, timeout=20):
        """
        Delete table with table_name

        :type  table_name: str
        :param table_name: Name of the table being deleted

        :return: Status, indicate if operation is successful
        :rtype: Status
        """

        table_name = Prepare.table_name(table_name)

        try:
            status = self._stub.DropTable.future(table_name).result(timeout=timeout)
            if status.error_code == 0:
                return Status(message='Delete collection successfully!')
            return Status(code=status.error_code, message=status.reason)
        except grpc.FutureTimeoutError as e:
            LOGGER.error(e)
            return Status(Status.UNEXPECTED_ERROR, message='Request timeout')
        except grpc.RpcError as e:
            LOGGER.error(e)
            return Status(e.code(), message='Error occurred: {}'.format(e.details()))

    def insert(self, table_name, records, ids=None, partition_tag=None, params=None, timeout=None, **kwargs):
        """
        Add vectors to table

        :param ids: list of id
        :type  ids: list[int]

        :type  table_name: str
        :param table_name: table name been inserted

        :type  records: list[list[float]]

                `example records: [[1.2345],[1.2345]]`

                `OR using Prepare.records`

        :param records: list of vectors been inserted

        :type partition_tag: str or None.
            If partition_tag is None, vectors will be inserted into table rather than partitions.

        :param partition_tag: the tag string of table

        :type

        :type  timeout: int
        :param timeout: time waiting for server response

        :returns:
            Status: indicate if vectors inserted successfully
            ids: list of id, after inserted every vector is given a id
        :rtype: (Status, list(int))
        """
        insert_param = kwargs.get('insert_param', None)

        if insert_param and not isinstance(insert_param, grpc_types.InsertParam):
            raise ParamError("The value of key 'insert_param' is invalid")

        body = insert_param if insert_param \
            else Prepare.insert_param(table_name, records, partition_tag, ids, params)

        try:
            response = self._stub.Insert.future(body).result(timeout=timeout)

            if response.status.error_code == 0:
                return Status(message='Add vectors successfully!'), list(response.vector_id_array)

            return Status(code=response.status.error_code, message=response.status.reason), []
        except grpc.RpcError as e:
            LOGGER.error(e)
            return Status(e.code(), message='Error occurred. {}'.format(e.details())), []
        except grpc.FutureTimeoutError as e:
            LOGGER.error(e)
            return Status(code=Status.UNEXPECTED_ERROR, message="Request timeout"), []

    def get_vector_by_id(self, table_name, v_id, timeout=10):
        request = grpc_types.VectorIdentity(table_name=table_name, id=v_id)

        try:
            response = self._stub.GetVectorByID.future(request).result(timeout=timeout)
            status = response.status
            if status.error_code == 0:
                status = Status(message="Obtain vector successfully")
                return status, \
                       list(response.vector_data.float_data) or bytes(response.vector_data.binary_data)

            return Status(code=status.error_code, message=status.reason), []
        except grpc.FutureTimeoutError as e:
            LOGGER.error(e)
            return Status(Status.UNEXPECTED_ERROR, message='Request timeout'), []
        except grpc.RpcError as e:
            LOGGER.error(e)
            return Status(e.code(), message='Error occurred: {}'.format(e.details())), []

    def get_vector_ids(self, table_name, segment_name, timeout=10):
        request = grpc_types.GetVectorIDsParam(table_name=table_name, segment_name=segment_name)

        try:
            response = self._stub.GetVectorIDs.future(request).result(timeout=timeout)

            if response.status.error_code == 0:
                vec = list(response.vector_id_array)
                return Status(), vec
            return Status(response.status.error_code, response.status.reason), []
        except grpc.FutureTimeoutError as e:
            LOGGER.error(e)
            return Status(Status.UNEXPECTED_ERROR, message="Request timeout"), []
        except grpc.RpcError as e:
            LOGGER.error(e)
            return Status(e.code(), message="Error occurred: {}".format(e.details())), []

    def create_index(self, table_name, index_type=None, params=None, timeout=None):
        """
        build vectors of specific table and create vector index

        :param table_name: table used to crete index.
        :type table_name: str
        :param index: index params
        :type index: dict

            index_param can be None

            `example (default) param={'index_type': IndexType.FLAT,
                            'nlist': 16384}`

        :param timeout: grpc request timeout.

            if `timeout` = -1, method invoke a synchronous call, waiting util grpc response
            else method invoke a asynchronous call, timeout work here

        :type  timeout: int

        :return: Status, indicate if operation is successful
        """
        index_param = Prepare.index_param(table_name, index_type, params)
        try:
            status = self._stub.CreateIndex.future(index_param).result(timeout=timeout)

            if status.error_code == 0:
                return Status(message='Build index successfully!')

            return Status(code=status.error_code, message=status.reason)
        except grpc.FutureTimeoutError as e:
            LOGGER.error(e)
            return Status(Status.UNEXPECTED_ERROR, message='Request timeout')
        except grpc.RpcError as e:
            LOGGER.error(e)
            return Status(e.code(), message='Error occurred. {}'.format(e.details()))

    def describe_index(self, table_name, timeout=10):
        """
        Show index information of designated table

        :type table_name: str
        :param table_name: table name been queried

        :returns:
            Status:  indicate if query is successful
            IndexSchema:

        """

        table_name = Prepare.table_name(table_name)

        try:
            index_param = self._stub.DescribeIndex.future(table_name).result(timeout=timeout)

            status = index_param.status

            if status.error_code == 0:
                return Status(message="Successfully"), \
                       IndexParam(index_param.table_name,
                                  index_param.index_type,
                                  index_param.extra_params)

            return Status(code=status.error_code, message=status.reason), None
        except grpc.FutureTimeoutError as e:
            LOGGER.error(e)
            return Status(code=Status.UNEXPECTED_ERROR, message='Request timeout'), None
        except grpc.RpcError as e:
            LOGGER.error(e)
            return Status(e.code(), message='Error occurred. {}'.format(e.details())), None

    def drop_index(self, table_name, timeout=10):
        """
        drop index from index file

        :param table_name: target table name.
        :type table_name: str

        :return:
            Status: indicate if operation is successful

        ：:rtype: Status
        """

        table_name = Prepare.table_name(table_name)
        try:
            status = self._stub.DropIndex.future(table_name).result(timeout=timeout)
            return Status(code=status.error_code, message=status.reason)
        except grpc.FutureTimeoutError as e:
            LOGGER.error(e)
            return Status(Status.UNEXPECTED_ERROR, message='Request timeout')
        except grpc.RpcError as e:
            LOGGER.error(e)
            return Status(e.code(), message='Error occurred. {}'.format(e.details()))

    def create_partition(self, table_name, partition_tag, timeout=10):
        """
        create a specific partition under designated table. After done, the meta file in
        milvus server update partition information, you can perform actions about partitions
        with partition tag.

        :param table_name: target table name.
        :type  table_name: str

        :param partition_name: name of target partition under designated table.
        :type  partition_name: str

        :param partition_tag: tag name of target partition under designated table.
        :type  partition_tag: str

        :param timeout: time waiting for response.
        :type  timeout: int

       :return:
            Status: indicate if operation is successful

        """
        request = Prepare.partition_param(table_name, partition_tag)

        try:
            response = self._stub.CreatePartition.future(request).result(timeout=timeout)
            return Status(code=response.error_code, message=response.reason)
        except grpc.FutureTimeoutError as e:
            LOGGER.error(e)
            return Status(code=Status.UNEXPECTED_ERROR, message='Request timeout.')
        except grpc.RpcError as e:
            LOGGER.error(e)
            return Status(e.code(), message='Error occurred. {}'.format(e.details()))

    def show_partitions(self, table_name, timeout=10):
        """
        Show all partitions under designated table.

        :param table_name: target table name.
        :type  table_name: str

        :param timeout: time waiting for response.
        :type  timeout: int

        :return:
            Status: indicate if operation is successful
            partition_list:

        """
        request = Prepare.table_name(table_name)

        try:
            response = self._stub.ShowPartitions.future(request).result(timeout=timeout)
            status = response.status
            if status.error_code == 0:

                partition_list = [PartitionParam(table_name, p) for p in response.partition_tag_array]
                return Status(), partition_list

            return Status(code=status.error_code, message=status.reason), []
        except grpc.FutureTimeoutError as e:
            LOGGER.error(e)
            return Status(code=Status.UNEXPECTED_ERROR, message="request timeout"), []
        except grpc.RpcError as e:
            LOGGER.error(e)
            return Status(e.code(), message='Error occurred. {}'.format(e.details())), []

    def drop_partition(self, table_name, partition_tag, timeout=10):
        """
        Drop specific partition under designated table.

        :param table_name: target table name.
        :type  table_name: str

        :param partition_tag: tag name of specific partition
        :type  partition_tag: str

        :param timeout: time waiting for response.
        :type  timeout: int

        :return:
            Status: indicate if operation is successful

        """
        request = grpc_types.PartitionParam(table_name=table_name, tag=partition_tag)

        try:
            response = self._stub.DropPartition.future(request).result(timeout=timeout)
            return Status(code=response.error_code, message=response.reason)
        except grpc.FutureTimeoutError as e:
            LOGGER.error(e)
            return Status(code=Status.UNEXPECTED_ERROR, message="request timeout")
        except grpc.RpcError as e:
            LOGGER.error(e)
            return Status(e.code(), message='Error occurred. {}'.format(e.details()))

    def search(self, table_name, top_k, query_records, partition_tags=None, params=None, **kwargs):
        """
        Search similar vectors in designated table

        :param table_name: target table name
        :type  table_name: str

        :param top_k: number of vertors which is most similar with query vectors
        :type  top_k: int

        :param nprobe: cell number of probe
        :type  nprobe: int

        :param query_records: vectors to query
        :type  query_records: list[list[float32]]

        :param partition_tags: tags to search
        :type  partition_tags: list

        :return
            Status: indicate if search successfully
            result: query result

        :rtype: (Status, TopKQueryResult)

        """

        request = Prepare.search_param(table_name, top_k, query_records, partition_tags, params)

        try:
            self._search_hook.pre_search()
            response = self._stub.Search(request)
            self._search_hook.aft_search()

            if self._search_hook.on_response():
                return response

            if response.status.error_code != 0:
                return Status(code=response.status.error_code,
                              message=response.status.reason), []

            resutls = self._search_hook.handle_response(response)
            return Status(message='Search vectors successfully!'), resutls

        except grpc.RpcError as e:
            LOGGER.error(e)
            status = Status(code=e.code(), message='Error occurred: {}'.format(e.details()))
            return status, []

    # def search_by_id(self, table_name, top_k, nprobe, id_, partition_tag_array):
    #
    #     request = Prepare.search_by_id_param(table_name, top_k, nprobe,
    #                                          id_, partition_tag_array)
    #
    #     try:
    #         response = self._stub.SearchByID(request)
    #         if response.status.error_code == 0:
    #             return Status(message='Search vectors successfully!'), TopKQueryResult(response)
    #
    #         return Status(code=response.status.error_code, message=response.status.reason), None
    #     except grpc.RpcError as e:
    #         LOGGER.error(e)
    #         status = Status(code=e.code(), message='Error occurred: {}'.format(e.details()))
    #         return status, None

    def search_in_files(self, table_name, file_ids, query_records, top_k, params):
        """
        Query vectors in a table, in specified files.

        The server store vector data into multiple files if the size of vectors
        exceeds file size threshold. It is supported to search in several files
        by specifying file ids. However, these file ids are stored in db in server,
        and python sdk doesn't apply any APIs get them at client. It's a specific
        method used in shards. Obtain more detail about milvus shards, see
        <a href="https://github.com/milvus-io/milvus/tree/0.6.0/shards">

        :type  table_name: str
        :param table_name: table name been queried

        :type  file_ids: list[str] or list[int]
        :param file_ids: Specified files id array

        :type  query_records: list[list[float]]
        :param query_records: all vectors going to be queried

        :param query_ranges: Optional ranges for conditional search.
            If not specified, search in the whole table

        :type  top_k: int
        :param top_k: how many similar vectors will be searched

        :returns:
            Status:  indicate if query is successful
            results: query result

        :rtype: (Status, TopKQueryResult)
        """

        file_ids = list(map(int_or_str, file_ids))
        # import pdb;pdb.set_trace()
        infos = Prepare.search_vector_in_files_param(
            table_name, query_records, top_k, file_ids, params
        )

        try:
            self._search_file_hook.pre_search()
            response = self._stub.SearchInFiles(infos)
            self._search_file_hook.aft_search()

            if self._search_file_hook.on_response():
                return response

            if response.status.error_code != 0:
                return Status(code=response.status.error_code,
                              message=response.status.reason), []

            return Status(message='Search vectors successfully!'), \
                   self._search_file_hook.handle_response(response)
        except grpc.RpcError as e:
            LOGGER.error(e)
            status = Status(code=e.code(), message='Error occurred. {}'.format(e.details()))
            return status, []

    def __delete_vectors_by_range(self, table_name, start_date=None, end_date=None, timeout=10):
        """
        Delete vectors by range. The data range contains start_time but not end_time
        This method is deprecated, not recommended for users.

        This API is deprecated.

        :type  table_name: str
        :param table_name: str, date, datetime

        :type  start_date: str, date, datetime
        :param start_date:

        :type  end_date: str, date, datetime
        :param end_date:

        :return:
            Status:  indicate if invoke is successful
        """

        if not self.connected():
            raise NotConnectError('Please connect to the server first')

        delete_range = Prepare.delete_param(table_name, start_date, end_date)

        try:
            status = self._stub.DeleteByDate.future(delete_range).result(timeout=timeout)
            return Status(code=status.error_code, message=status.reason)
        except grpc.FutureTimeoutError as e:
            LOGGER.error(e)
            return Status(Status.UNEXPECTED_ERROR, message='Request timeout')
        except grpc.RpcError as e:
            LOGGER.error(e)
            return Status(e.code(), message='Error occurred. {}'.format(e.details()))

    def delete_by_id(self, table_name, id_array, timeout=None):

        request = Prepare.delete_by_id_param(table_name, id_array)

        try:
            status = self._stub.DeleteByID.future(request).result(timeout=timeout)
            return Status(code=status.error_code, message=status.reason)
        except grpc.FutureTimeoutError as e:
            LOGGER.error(e)
            return Status(Status.UNEXPECTED_ERROR, message='Request timeout')
        except grpc.RpcError as e:
            LOGGER.error(e)
            return Status(e.code(), message='Error occurred. {}'.format(e.details()))

    def flush(self, table_name_array):
        request = Prepare.flush_param(table_name_array)

        try:
            response = self._stub.Flush(request)
            return Status(code=response.error_code, message=response.reason)
        except grpc.RpcError as e:
            LOGGER.error(e)
            return Status(e.code(), message='Error occurred. {}'.format(e.details()))

    def compact(self, table_name, timeout):
        request = Prepare.compact_param(table_name)

        try:
            response = self._stub.Compact(request)
            return Status(code=response.error_code, message=response.reason)
        except grpc.RpcError as e:
            LOGGER.error(e)
            return Status(e.code(), message='Error occurred. {}'.format(e.details()))

    def set_config(self, parent_key, child_key, value):
        cmd = "set_config {}.{} {}".format(parent_key, child_key, value)
        return self._cmd(cmd)

    def get_config(self, parent_key, child_key):
        cmd = "get_config {}.{}".format(parent_key, child_key)
        return self._cmd(cmd)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: status.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='status.proto',
    package='milvus.grpc',
    syntax='proto3',
    serialized_options=None,
    serialized_pb=_b(
        '\n\x0cstatus.proto\x12\x0bmilvus.grpc\"D\n\x06Status\x12*\n\nerror_code\x18\x01 \x01(\x0e\x32\x16.milvus.grpc.ErrorCode\x12\x0e\n\x06reason\x18\x02 \x01(\t*\x98\x04\n\tErrorCode\x12\x0b\n\x07SUCCESS\x10\x00\x12\x14\n\x10UNEXPECTED_ERROR\x10\x01\x12\x12\n\x0e\x43ONNECT_FAILED\x10\x02\x12\x15\n\x11PERMISSION_DENIED\x10\x03\x12\x14\n\x10TABLE_NOT_EXISTS\x10\x04\x12\x14\n\x10ILLEGAL_ARGUMENT\x10\x05\x12\x15\n\x11ILLEGAL_DIMENSION\x10\x07\x12\x16\n\x12ILLEGAL_INDEX_TYPE\x10\x08\x12\x16\n\x12ILLEGAL_TABLE_NAME\x10\t\x12\x10\n\x0cILLEGAL_TOPK\x10\n\x12\x15\n\x11ILLEGAL_ROWRECORD\x10\x0b\x12\x15\n\x11ILLEGAL_VECTOR_ID\x10\x0c\x12\x19\n\x15ILLEGAL_SEARCH_RESULT\x10\r\x12\x12\n\x0e\x46ILE_NOT_FOUND\x10\x0e\x12\x0f\n\x0bMETA_FAILED\x10\x0f\x12\x10\n\x0c\x43\x41\x43HE_FAILED\x10\x10\x12\x18\n\x14\x43\x41NNOT_CREATE_FOLDER\x10\x11\x12\x16\n\x12\x43\x41NNOT_CREATE_FILE\x10\x12\x12\x18\n\x14\x43\x41NNOT_DELETE_FOLDER\x10\x13\x12\x16\n\x12\x43\x41NNOT_DELETE_FILE\x10\x14\x12\x15\n\x11\x42UILD_INDEX_ERROR\x10\x15\x12\x11\n\rILLEGAL_NLIST\x10\x16\x12\x17\n\x13ILLEGAL_METRIC_TYPE\x10\x17\x12\x11\n\rOUT_OF_MEMORY\x10\x18\x62\x06proto3')
)

_ERRORCODE = _descriptor.EnumDescriptor(
    name='ErrorCode',
    full_name='milvus.grpc.ErrorCode',
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name='SUCCESS', index=0, number=0,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='UNEXPECTED_ERROR', index=1, number=1,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='CONNECT_FAILED', index=2, number=2,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='PERMISSION_DENIED', index=3, number=3,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='TABLE_NOT_EXISTS', index=4, number=4,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='ILLEGAL_ARGUMENT', index=5, number=5,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='ILLEGAL_DIMENSION', index=6, number=7,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='ILLEGAL_INDEX_TYPE', index=7, number=8,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='ILLEGAL_TABLE_NAME', index=8, number=9,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='ILLEGAL_TOPK', index=9, number=10,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='ILLEGAL_ROWRECORD', index=10, number=11,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='ILLEGAL_VECTOR_ID', index=11, number=12,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='ILLEGAL_SEARCH_RESULT', index=12, number=13,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='FILE_NOT_FOUND', index=13, number=14,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='META_FAILED', index=14, number=15,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='CACHE_FAILED', index=15, number=16,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='CANNOT_CREATE_FOLDER', index=16, number=17,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='CANNOT_CREATE_FILE', index=17, number=18,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='CANNOT_DELETE_FOLDER', index=18, number=19,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='CANNOT_DELETE_FILE', index=19, number=20,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='BUILD_INDEX_ERROR', index=20, number=21,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='ILLEGAL_NLIST', index=21, number=22,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='ILLEGAL_METRIC_TYPE', index=22, number=23,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='OUT_OF_MEMORY', index=23, number=24,
            serialized_options=None,
            type=None),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=100,
    serialized_end=636,
)
_sym_db.RegisterEnumDescriptor(_ERRORCODE)

ErrorCode = enum_type_wrapper.EnumTypeWrapper(_ERRORCODE)
SUCCESS = 0
UNEXPECTED_ERROR = 1
CONNECT_FAILED = 2
PERMISSION_DENIED = 3
TABLE_NOT_EXISTS = 4
ILLEGAL_ARGUMENT = 5
ILLEGAL_DIMENSION = 7
ILLEGAL_INDEX_TYPE = 8
ILLEGAL_TABLE_NAME = 9
ILLEGAL_TOPK = 10
ILLEGAL_ROWRECORD = 11
ILLEGAL_VECTOR_ID = 12
ILLEGAL_SEARCH_RESULT = 13
FILE_NOT_FOUND = 14
META_FAILED = 15
CACHE_FAILED = 16
CANNOT_CREATE_FOLDER = 17
CANNOT_CREATE_FILE = 18
CANNOT_DELETE_FOLDER = 19
CANNOT_DELETE_FILE = 20
BUILD_INDEX_ERROR = 21
ILLEGAL_NLIST = 22
ILLEGAL_METRIC_TYPE = 23
OUT_OF_MEMORY = 24

_STATUS = _descriptor.Descriptor(
    name='Status',
    full_name='milvus.grpc.Status',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='error_code', full_name='milvus.grpc.Status.error_code', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='reason', full_name='milvus.grpc.Status.reason', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=29,
    serialized_end=97,
)

_STATUS.fields_by_name['error_code'].enum_type = _ERRORCODE
DESCRIPTOR.message_types_by_name['Status'] = _STATUS
DESCRIPTOR.enum_types_by_name['ErrorCode'] = _ERRORCODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Status = _reflection.GeneratedProtocolMessageType('Status', (_message.Message,), {
    'DESCRIPTOR': _STATUS,
    '__module__': 'status_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.Status)
})
_sym_db.RegisterMessage(Status)

# @@protoc_insertion_point(module_scope)



import copy

import ujson

from ..grpc_gen import milvus_pb2 as grpc_types
from ..grpc_gen import status_pb2


class Prepare:

    @classmethod
    def table_name(cls, table_name):

        return grpc_types.TableName(table_name=table_name)

    @classmethod
    def table_schema(cls, table_name, dimension, index_file_size, metric_type, param):
        """
        :type param: dict
        :param param: (Required)

            `example param={'table_name': 'name',
                            'dimension': 16,
                            'index_file_size': 1024
                            'metric_type': MetricType.L2
                            }`

        :return: ttypes.TableSchema object
        """

        _param = grpc_types.TableSchema(status=status_pb2.Status(error_code=0, reason='Client'),
                                        table_name=table_name,
                                        dimension=dimension,
                                        index_file_size=index_file_size,
                                        metric_type=metric_type)

        if param:
            param_str = ujson.dumps(param)
            _param.extra_params.add(key="params", value=param_str)

        return _param

    @classmethod
    def insert_param(cls, table_name, vectors, partition_tag, ids=None, params=None, **kwargs):

        if ids is None:
            _param = grpc_types.InsertParam(table_name=table_name, partition_tag=partition_tag)
        else:
            _param = grpc_types.InsertParam(
                table_name=table_name,
                row_id_array=ids,
                partition_tag=partition_tag)

        for vector in vectors:
            if isinstance(vector, bytes):
                _param.row_record_array.add(binary_data=vector)
            else:
                _param.row_record_array.add(float_data=vector)

        params = params or dict()
        params_str = ujson.dumps(params)
        _param.extra_params.add(key="params", value=params_str)

        return _param

    @classmethod
    def index_param(cls, table_name, index_type, params):

        _param = grpc_types.IndexParam(status=status_pb2.Status(error_code=0, reason='Client'),
                                       table_name=table_name,
                                       index_type=index_type)
        params = params or dict()
        params_str = ujson.dumps(params)
        _param.extra_params.add(key="params", value=params_str)

        return _param

    @classmethod
    def search_param(cls, table_name, topk, query_records, partitions, params):

        search_param = grpc_types.SearchParam(
            table_name=table_name,
            topk=topk,
            partition_tag_array=partitions
        )

        for vector in query_records:
            if isinstance(vector, bytes):
                search_param.query_record_array.add(binary_data=vector)
            else:
                search_param.query_record_array.add(float_data=vector)

        params = params or dict()
        params_str = ujson.dumps(params)
        search_param.extra_params.add(key="params", value=params_str)

        return search_param

    @classmethod
    def search_by_id_param(cls, table_name, top_k, id_, partition_tag_array, params):
        _param = grpc_types.SearchByIDParam(
            table_name=table_name, id=id_, topk=top_k,
            partition_tag_array=partition_tag_array
        )

        params = params or dict()
        params_str = ujson.dumps(params)
        _param.extra_params.add(key="params", value=params_str)

        return _param

    @classmethod
    def search_vector_in_files_param(cls, table_name, query_records, topk, ids, params):
        _search_param = Prepare.search_param(table_name, topk, query_records,
                                             partitions=[], params=params)

        return grpc_types.SearchInFilesParam(
            file_id_array=ids,
            search_param=_search_param
        )

    @classmethod
    def cmd(cls, cmd):

        return grpc_types.Command(cmd=cmd)

    @classmethod
    def partition_param(cls, table_name, tag):

        return grpc_types.PartitionParam(table_name=table_name, tag=tag)

    @classmethod
    def delete_by_id_param(cls, table_name, id_array):

        return grpc_types.DeleteByIDParam(table_name=table_name, id_array=id_array)

    @classmethod
    def flush_param(cls, table_names):

        return grpc_types.FlushParam(table_name_array=table_names)

    @classmethod
    def compact_param(cls, table_name):
        return grpc_types.TableName(table_name=table_name)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: milvus.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from . import status_pb2 as status__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='milvus.proto',
    package='milvus.grpc',
    syntax='proto3',
    serialized_options=None,
    serialized_pb=_b(
        '\n\x0cmilvus.proto\x12\x0bmilvus.grpc\x1a\x0cstatus.proto\"*\n\x0cKeyValuePair\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\x1f\n\tTableName\x12\x12\n\ntable_name\x18\x01 \x01(\t\"I\n\rTableNameList\x12#\n\x06status\x18\x01 \x01(\x0b\x32\x13.milvus.grpc.Status\x12\x13\n\x0btable_names\x18\x02 \x03(\t\"\xb8\x01\n\x0bTableSchema\x12#\n\x06status\x18\x01 \x01(\x0b\x32\x13.milvus.grpc.Status\x12\x12\n\ntable_name\x18\x02 \x01(\t\x12\x11\n\tdimension\x18\x03 \x01(\x03\x12\x17\n\x0findex_file_size\x18\x04 \x01(\x03\x12\x13\n\x0bmetric_type\x18\x05 \x01(\x05\x12/\n\x0c\x65xtra_params\x18\x06 \x03(\x0b\x32\x19.milvus.grpc.KeyValuePair\"1\n\x0ePartitionParam\x12\x12\n\ntable_name\x18\x01 \x01(\t\x12\x0b\n\x03tag\x18\x02 \x01(\t\"Q\n\rPartitionList\x12#\n\x06status\x18\x01 \x01(\x0b\x32\x13.milvus.grpc.Status\x12\x1b\n\x13partition_tag_array\x18\x02 \x03(\t\"4\n\tRowRecord\x12\x12\n\nfloat_data\x18\x01 \x03(\x02\x12\x13\n\x0b\x62inary_data\x18\x02 \x01(\x0c\"\xb1\x01\n\x0bInsertParam\x12\x12\n\ntable_name\x18\x01 \x01(\t\x12\x30\n\x10row_record_array\x18\x02 \x03(\x0b\x32\x16.milvus.grpc.RowRecord\x12\x14\n\x0crow_id_array\x18\x03 \x03(\x03\x12\x15\n\rpartition_tag\x18\x04 \x01(\t\x12/\n\x0c\x65xtra_params\x18\x05 \x03(\x0b\x32\x19.milvus.grpc.KeyValuePair\"I\n\tVectorIds\x12#\n\x06status\x18\x01 \x01(\x0b\x32\x13.milvus.grpc.Status\x12\x17\n\x0fvector_id_array\x18\x02 \x03(\x03\"\xb1\x01\n\x0bSearchParam\x12\x12\n\ntable_name\x18\x01 \x01(\t\x12\x1b\n\x13partition_tag_array\x18\x02 \x03(\t\x12\x32\n\x12query_record_array\x18\x03 \x03(\x0b\x32\x16.milvus.grpc.RowRecord\x12\x0c\n\x04topk\x18\x04 \x01(\x03\x12/\n\x0c\x65xtra_params\x18\x05 \x03(\x0b\x32\x19.milvus.grpc.KeyValuePair\"[\n\x12SearchInFilesParam\x12\x15\n\rfile_id_array\x18\x01 \x03(\t\x12.\n\x0csearch_param\x18\x02 \x01(\x0b\x32\x18.milvus.grpc.SearchParam\"\x8d\x01\n\x0fSearchByIDParam\x12\x12\n\ntable_name\x18\x01 \x01(\t\x12\x1b\n\x13partition_tag_array\x18\x02 \x03(\t\x12\n\n\x02id\x18\x03 \x01(\x03\x12\x0c\n\x04topk\x18\x04 \x01(\x03\x12/\n\x0c\x65xtra_params\x18\x05 \x03(\x0b\x32\x19.milvus.grpc.KeyValuePair\"g\n\x0fTopKQueryResult\x12#\n\x06status\x18\x01 \x01(\x0b\x32\x13.milvus.grpc.Status\x12\x0f\n\x07row_num\x18\x02 \x01(\x03\x12\x0b\n\x03ids\x18\x03 \x03(\x03\x12\x11\n\tdistances\x18\x04 \x03(\x02\"H\n\x0bStringReply\x12#\n\x06status\x18\x01 \x01(\x0b\x32\x13.milvus.grpc.Status\x12\x14\n\x0cstring_reply\x18\x02 \x01(\t\"D\n\tBoolReply\x12#\n\x06status\x18\x01 \x01(\x0b\x32\x13.milvus.grpc.Status\x12\x12\n\nbool_reply\x18\x02 \x01(\x08\"M\n\rTableRowCount\x12#\n\x06status\x18\x01 \x01(\x0b\x32\x13.milvus.grpc.Status\x12\x17\n\x0ftable_row_count\x18\x02 \x01(\x03\"\x16\n\x07\x43ommand\x12\x0b\n\x03\x63md\x18\x01 \x01(\t\"\x8a\x01\n\nIndexParam\x12#\n\x06status\x18\x01 \x01(\x0b\x32\x13.milvus.grpc.Status\x12\x12\n\ntable_name\x18\x02 \x01(\t\x12\x12\n\nindex_type\x18\x03 \x01(\x05\x12/\n\x0c\x65xtra_params\x18\x04 \x03(\x0b\x32\x19.milvus.grpc.KeyValuePair\"&\n\nFlushParam\x12\x18\n\x10table_name_array\x18\x01 \x03(\t\"7\n\x0f\x44\x65leteByIDParam\x12\x12\n\ntable_name\x18\x01 \x01(\t\x12\x10\n\x08id_array\x18\x02 \x03(\x03\"]\n\x0bSegmentStat\x12\x14\n\x0csegment_name\x18\x01 \x01(\t\x12\x11\n\trow_count\x18\x02 \x01(\x03\x12\x12\n\nindex_name\x18\x03 \x01(\t\x12\x11\n\tdata_size\x18\x04 \x01(\x03\"f\n\rPartitionStat\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x17\n\x0ftotal_row_count\x18\x02 \x01(\x03\x12/\n\rsegments_stat\x18\x03 \x03(\x0b\x32\x18.milvus.grpc.SegmentStat\"~\n\tTableInfo\x12#\n\x06status\x18\x01 \x01(\x0b\x32\x13.milvus.grpc.Status\x12\x17\n\x0ftotal_row_count\x18\x02 \x01(\x03\x12\x33\n\x0fpartitions_stat\x18\x03 \x03(\x0b\x32\x1a.milvus.grpc.PartitionStat\"0\n\x0eVectorIdentity\x12\x12\n\ntable_name\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x03\"^\n\nVectorData\x12#\n\x06status\x18\x01 \x01(\x0b\x32\x13.milvus.grpc.Status\x12+\n\x0bvector_data\x18\x02 \x01(\x0b\x32\x16.milvus.grpc.RowRecord\"=\n\x11GetVectorIDsParam\x12\x12\n\ntable_name\x18\x01 \x01(\t\x12\x14\n\x0csegment_name\x18\x02 \x01(\t2\xcb\x0c\n\rMilvusService\x12>\n\x0b\x43reateTable\x12\x18.milvus.grpc.TableSchema\x1a\x13.milvus.grpc.Status\"\x00\x12<\n\x08HasTable\x12\x16.milvus.grpc.TableName\x1a\x16.milvus.grpc.BoolReply\"\x00\x12\x43\n\rDescribeTable\x12\x16.milvus.grpc.TableName\x1a\x18.milvus.grpc.TableSchema\"\x00\x12\x42\n\nCountTable\x12\x16.milvus.grpc.TableName\x1a\x1a.milvus.grpc.TableRowCount\"\x00\x12@\n\nShowTables\x12\x14.milvus.grpc.Command\x1a\x1a.milvus.grpc.TableNameList\"\x00\x12\x41\n\rShowTableInfo\x12\x16.milvus.grpc.TableName\x1a\x16.milvus.grpc.TableInfo\"\x00\x12:\n\tDropTable\x12\x16.milvus.grpc.TableName\x1a\x13.milvus.grpc.Status\"\x00\x12=\n\x0b\x43reateIndex\x12\x17.milvus.grpc.IndexParam\x1a\x13.milvus.grpc.Status\"\x00\x12\x42\n\rDescribeIndex\x12\x16.milvus.grpc.TableName\x1a\x17.milvus.grpc.IndexParam\"\x00\x12:\n\tDropIndex\x12\x16.milvus.grpc.TableName\x1a\x13.milvus.grpc.Status\"\x00\x12\x45\n\x0f\x43reatePartition\x12\x1b.milvus.grpc.PartitionParam\x1a\x13.milvus.grpc.Status\"\x00\x12\x46\n\x0eShowPartitions\x12\x16.milvus.grpc.TableName\x1a\x1a.milvus.grpc.PartitionList\"\x00\x12\x43\n\rDropPartition\x12\x1b.milvus.grpc.PartitionParam\x1a\x13.milvus.grpc.Status\"\x00\x12<\n\x06Insert\x12\x18.milvus.grpc.InsertParam\x1a\x16.milvus.grpc.VectorIds\"\x00\x12G\n\rGetVectorByID\x12\x1b.milvus.grpc.VectorIdentity\x1a\x17.milvus.grpc.VectorData\"\x00\x12H\n\x0cGetVectorIDs\x12\x1e.milvus.grpc.GetVectorIDsParam\x1a\x16.milvus.grpc.VectorIds\"\x00\x12\x42\n\x06Search\x12\x18.milvus.grpc.SearchParam\x1a\x1c.milvus.grpc.TopKQueryResult\"\x00\x12J\n\nSearchByID\x12\x1c.milvus.grpc.SearchByIDParam\x1a\x1c.milvus.grpc.TopKQueryResult\"\x00\x12P\n\rSearchInFiles\x12\x1f.milvus.grpc.SearchInFilesParam\x1a\x1c.milvus.grpc.TopKQueryResult\"\x00\x12\x37\n\x03\x43md\x12\x14.milvus.grpc.Command\x1a\x18.milvus.grpc.StringReply\"\x00\x12\x41\n\nDeleteByID\x12\x1c.milvus.grpc.DeleteByIDParam\x1a\x13.milvus.grpc.Status\"\x00\x12=\n\x0cPreloadTable\x12\x16.milvus.grpc.TableName\x1a\x13.milvus.grpc.Status\"\x00\x12\x37\n\x05\x46lush\x12\x17.milvus.grpc.FlushParam\x1a\x13.milvus.grpc.Status\"\x00\x12\x38\n\x07\x43ompact\x12\x16.milvus.grpc.TableName\x1a\x13.milvus.grpc.Status\"\x00\x62\x06proto3')
    ,
    dependencies=[status__pb2.DESCRIPTOR, ])

_KEYVALUEPAIR = _descriptor.Descriptor(
    name='KeyValuePair',
    full_name='milvus.grpc.KeyValuePair',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='key', full_name='milvus.grpc.KeyValuePair.key', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='value', full_name='milvus.grpc.KeyValuePair.value', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=43,
    serialized_end=85,
)

_TABLENAME = _descriptor.Descriptor(
    name='TableName',
    full_name='milvus.grpc.TableName',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='table_name', full_name='milvus.grpc.TableName.table_name', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=87,
    serialized_end=118,
)

_TABLENAMELIST = _descriptor.Descriptor(
    name='TableNameList',
    full_name='milvus.grpc.TableNameList',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='status', full_name='milvus.grpc.TableNameList.status', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='table_names', full_name='milvus.grpc.TableNameList.table_names', index=1,
            number=2, type=9, cpp_type=9, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=120,
    serialized_end=193,
)

_TABLESCHEMA = _descriptor.Descriptor(
    name='TableSchema',
    full_name='milvus.grpc.TableSchema',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='status', full_name='milvus.grpc.TableSchema.status', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='table_name', full_name='milvus.grpc.TableSchema.table_name', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='dimension', full_name='milvus.grpc.TableSchema.dimension', index=2,
            number=3, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='index_file_size', full_name='milvus.grpc.TableSchema.index_file_size', index=3,
            number=4, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='metric_type', full_name='milvus.grpc.TableSchema.metric_type', index=4,
            number=5, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='extra_params', full_name='milvus.grpc.TableSchema.extra_params', index=5,
            number=6, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=196,
    serialized_end=380,
)

_PARTITIONPARAM = _descriptor.Descriptor(
    name='PartitionParam',
    full_name='milvus.grpc.PartitionParam',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='table_name', full_name='milvus.grpc.PartitionParam.table_name', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='tag', full_name='milvus.grpc.PartitionParam.tag', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=382,
    serialized_end=431,
)

_PARTITIONLIST = _descriptor.Descriptor(
    name='PartitionList',
    full_name='milvus.grpc.PartitionList',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='status', full_name='milvus.grpc.PartitionList.status', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='partition_tag_array', full_name='milvus.grpc.PartitionList.partition_tag_array', index=1,
            number=2, type=9, cpp_type=9, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=433,
    serialized_end=514,
)

_ROWRECORD = _descriptor.Descriptor(
    name='RowRecord',
    full_name='milvus.grpc.RowRecord',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='float_data', full_name='milvus.grpc.RowRecord.float_data', index=0,
            number=1, type=2, cpp_type=6, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='binary_data', full_name='milvus.grpc.RowRecord.binary_data', index=1,
            number=2, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=516,
    serialized_end=568,
)

_INSERTPARAM = _descriptor.Descriptor(
    name='InsertParam',
    full_name='milvus.grpc.InsertParam',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='table_name', full_name='milvus.grpc.InsertParam.table_name', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='row_record_array', full_name='milvus.grpc.InsertParam.row_record_array', index=1,
            number=2, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='row_id_array', full_name='milvus.grpc.InsertParam.row_id_array', index=2,
            number=3, type=3, cpp_type=2, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='partition_tag', full_name='milvus.grpc.InsertParam.partition_tag', index=3,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='extra_params', full_name='milvus.grpc.InsertParam.extra_params', index=4,
            number=5, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=571,
    serialized_end=748,
)

_VECTORIDS = _descriptor.Descriptor(
    name='VectorIds',
    full_name='milvus.grpc.VectorIds',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='status', full_name='milvus.grpc.VectorIds.status', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='vector_id_array', full_name='milvus.grpc.VectorIds.vector_id_array', index=1,
            number=2, type=3, cpp_type=2, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=750,
    serialized_end=823,
)

_SEARCHPARAM = _descriptor.Descriptor(
    name='SearchParam',
    full_name='milvus.grpc.SearchParam',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='table_name', full_name='milvus.grpc.SearchParam.table_name', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='partition_tag_array', full_name='milvus.grpc.SearchParam.partition_tag_array', index=1,
            number=2, type=9, cpp_type=9, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='query_record_array', full_name='milvus.grpc.SearchParam.query_record_array', index=2,
            number=3, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='topk', full_name='milvus.grpc.SearchParam.topk', index=3,
            number=4, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='extra_params', full_name='milvus.grpc.SearchParam.extra_params', index=4,
            number=5, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=826,
    serialized_end=1003,
)

_SEARCHINFILESPARAM = _descriptor.Descriptor(
    name='SearchInFilesParam',
    full_name='milvus.grpc.SearchInFilesParam',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='file_id_array', full_name='milvus.grpc.SearchInFilesParam.file_id_array', index=0,
            number=1, type=9, cpp_type=9, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='search_param', full_name='milvus.grpc.SearchInFilesParam.search_param', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1005,
    serialized_end=1096,
)

_SEARCHBYIDPARAM = _descriptor.Descriptor(
    name='SearchByIDParam',
    full_name='milvus.grpc.SearchByIDParam',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='table_name', full_name='milvus.grpc.SearchByIDParam.table_name', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='partition_tag_array', full_name='milvus.grpc.SearchByIDParam.partition_tag_array', index=1,
            number=2, type=9, cpp_type=9, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='id', full_name='milvus.grpc.SearchByIDParam.id', index=2,
            number=3, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='topk', full_name='milvus.grpc.SearchByIDParam.topk', index=3,
            number=4, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='extra_params', full_name='milvus.grpc.SearchByIDParam.extra_params', index=4,
            number=5, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1099,
    serialized_end=1240,
)

_TOPKQUERYRESULT = _descriptor.Descriptor(
    name='TopKQueryResult',
    full_name='milvus.grpc.TopKQueryResult',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='status', full_name='milvus.grpc.TopKQueryResult.status', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='row_num', full_name='milvus.grpc.TopKQueryResult.row_num', index=1,
            number=2, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='ids', full_name='milvus.grpc.TopKQueryResult.ids', index=2,
            number=3, type=3, cpp_type=2, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='distances', full_name='milvus.grpc.TopKQueryResult.distances', index=3,
            number=4, type=2, cpp_type=6, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1242,
    serialized_end=1345,
)

_STRINGREPLY = _descriptor.Descriptor(
    name='StringReply',
    full_name='milvus.grpc.StringReply',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='status', full_name='milvus.grpc.StringReply.status', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='string_reply', full_name='milvus.grpc.StringReply.string_reply', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1347,
    serialized_end=1419,
)

_BOOLREPLY = _descriptor.Descriptor(
    name='BoolReply',
    full_name='milvus.grpc.BoolReply',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='status', full_name='milvus.grpc.BoolReply.status', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='bool_reply', full_name='milvus.grpc.BoolReply.bool_reply', index=1,
            number=2, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1421,
    serialized_end=1489,
)

_TABLEROWCOUNT = _descriptor.Descriptor(
    name='TableRowCount',
    full_name='milvus.grpc.TableRowCount',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='status', full_name='milvus.grpc.TableRowCount.status', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='table_row_count', full_name='milvus.grpc.TableRowCount.table_row_count', index=1,
            number=2, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1491,
    serialized_end=1568,
)

_COMMAND = _descriptor.Descriptor(
    name='Command',
    full_name='milvus.grpc.Command',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='cmd', full_name='milvus.grpc.Command.cmd', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1570,
    serialized_end=1592,
)

_INDEXPARAM = _descriptor.Descriptor(
    name='IndexParam',
    full_name='milvus.grpc.IndexParam',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='status', full_name='milvus.grpc.IndexParam.status', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='table_name', full_name='milvus.grpc.IndexParam.table_name', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='index_type', full_name='milvus.grpc.IndexParam.index_type', index=2,
            number=3, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='extra_params', full_name='milvus.grpc.IndexParam.extra_params', index=3,
            number=4, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1595,
    serialized_end=1733,
)

_FLUSHPARAM = _descriptor.Descriptor(
    name='FlushParam',
    full_name='milvus.grpc.FlushParam',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='table_name_array', full_name='milvus.grpc.FlushParam.table_name_array', index=0,
            number=1, type=9, cpp_type=9, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1735,
    serialized_end=1773,
)

_DELETEBYIDPARAM = _descriptor.Descriptor(
    name='DeleteByIDParam',
    full_name='milvus.grpc.DeleteByIDParam',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='table_name', full_name='milvus.grpc.DeleteByIDParam.table_name', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='id_array', full_name='milvus.grpc.DeleteByIDParam.id_array', index=1,
            number=2, type=3, cpp_type=2, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1775,
    serialized_end=1830,
)

_SEGMENTSTAT = _descriptor.Descriptor(
    name='SegmentStat',
    full_name='milvus.grpc.SegmentStat',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='segment_name', full_name='milvus.grpc.SegmentStat.segment_name', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='row_count', full_name='milvus.grpc.SegmentStat.row_count', index=1,
            number=2, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='index_name', full_name='milvus.grpc.SegmentStat.index_name', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='data_size', full_name='milvus.grpc.SegmentStat.data_size', index=3,
            number=4, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1832,
    serialized_end=1925,
)

_PARTITIONSTAT = _descriptor.Descriptor(
    name='PartitionStat',
    full_name='milvus.grpc.PartitionStat',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='tag', full_name='milvus.grpc.PartitionStat.tag', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='total_row_count', full_name='milvus.grpc.PartitionStat.total_row_count', index=1,
            number=2, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='segments_stat', full_name='milvus.grpc.PartitionStat.segments_stat', index=2,
            number=3, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1927,
    serialized_end=2029,
)

_TABLEINFO = _descriptor.Descriptor(
    name='TableInfo',
    full_name='milvus.grpc.TableInfo',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='status', full_name='milvus.grpc.TableInfo.status', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='total_row_count', full_name='milvus.grpc.TableInfo.total_row_count', index=1,
            number=2, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='partitions_stat', full_name='milvus.grpc.TableInfo.partitions_stat', index=2,
            number=3, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=2031,
    serialized_end=2157,
)

_VECTORIDENTITY = _descriptor.Descriptor(
    name='VectorIdentity',
    full_name='milvus.grpc.VectorIdentity',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='table_name', full_name='milvus.grpc.VectorIdentity.table_name', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='id', full_name='milvus.grpc.VectorIdentity.id', index=1,
            number=2, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=2159,
    serialized_end=2207,
)

_VECTORDATA = _descriptor.Descriptor(
    name='VectorData',
    full_name='milvus.grpc.VectorData',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='status', full_name='milvus.grpc.VectorData.status', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='vector_data', full_name='milvus.grpc.VectorData.vector_data', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=2209,
    serialized_end=2303,
)

_GETVECTORIDSPARAM = _descriptor.Descriptor(
    name='GetVectorIDsParam',
    full_name='milvus.grpc.GetVectorIDsParam',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='table_name', full_name='milvus.grpc.GetVectorIDsParam.table_name', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='segment_name', full_name='milvus.grpc.GetVectorIDsParam.segment_name', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=2305,
    serialized_end=2366,
)

_TABLENAMELIST.fields_by_name['status'].message_type = status__pb2._STATUS
_TABLESCHEMA.fields_by_name['status'].message_type = status__pb2._STATUS
_TABLESCHEMA.fields_by_name['extra_params'].message_type = _KEYVALUEPAIR
_PARTITIONLIST.fields_by_name['status'].message_type = status__pb2._STATUS
_INSERTPARAM.fields_by_name['row_record_array'].message_type = _ROWRECORD
_INSERTPARAM.fields_by_name['extra_params'].message_type = _KEYVALUEPAIR
_VECTORIDS.fields_by_name['status'].message_type = status__pb2._STATUS
_SEARCHPARAM.fields_by_name['query_record_array'].message_type = _ROWRECORD
_SEARCHPARAM.fields_by_name['extra_params'].message_type = _KEYVALUEPAIR
_SEARCHINFILESPARAM.fields_by_name['search_param'].message_type = _SEARCHPARAM
_SEARCHBYIDPARAM.fields_by_name['extra_params'].message_type = _KEYVALUEPAIR
_TOPKQUERYRESULT.fields_by_name['status'].message_type = status__pb2._STATUS
_STRINGREPLY.fields_by_name['status'].message_type = status__pb2._STATUS
_BOOLREPLY.fields_by_name['status'].message_type = status__pb2._STATUS
_TABLEROWCOUNT.fields_by_name['status'].message_type = status__pb2._STATUS
_INDEXPARAM.fields_by_name['status'].message_type = status__pb2._STATUS
_INDEXPARAM.fields_by_name['extra_params'].message_type = _KEYVALUEPAIR
_PARTITIONSTAT.fields_by_name['segments_stat'].message_type = _SEGMENTSTAT
_TABLEINFO.fields_by_name['status'].message_type = status__pb2._STATUS
_TABLEINFO.fields_by_name['partitions_stat'].message_type = _PARTITIONSTAT
_VECTORDATA.fields_by_name['status'].message_type = status__pb2._STATUS
_VECTORDATA.fields_by_name['vector_data'].message_type = _ROWRECORD
DESCRIPTOR.message_types_by_name['KeyValuePair'] = _KEYVALUEPAIR
DESCRIPTOR.message_types_by_name['TableName'] = _TABLENAME
DESCRIPTOR.message_types_by_name['TableNameList'] = _TABLENAMELIST
DESCRIPTOR.message_types_by_name['TableSchema'] = _TABLESCHEMA
DESCRIPTOR.message_types_by_name['PartitionParam'] = _PARTITIONPARAM
DESCRIPTOR.message_types_by_name['PartitionList'] = _PARTITIONLIST
DESCRIPTOR.message_types_by_name['RowRecord'] = _ROWRECORD
DESCRIPTOR.message_types_by_name['InsertParam'] = _INSERTPARAM
DESCRIPTOR.message_types_by_name['VectorIds'] = _VECTORIDS
DESCRIPTOR.message_types_by_name['SearchParam'] = _SEARCHPARAM
DESCRIPTOR.message_types_by_name['SearchInFilesParam'] = _SEARCHINFILESPARAM
DESCRIPTOR.message_types_by_name['SearchByIDParam'] = _SEARCHBYIDPARAM
DESCRIPTOR.message_types_by_name['TopKQueryResult'] = _TOPKQUERYRESULT
DESCRIPTOR.message_types_by_name['StringReply'] = _STRINGREPLY
DESCRIPTOR.message_types_by_name['BoolReply'] = _BOOLREPLY
DESCRIPTOR.message_types_by_name['TableRowCount'] = _TABLEROWCOUNT
DESCRIPTOR.message_types_by_name['Command'] = _COMMAND
DESCRIPTOR.message_types_by_name['IndexParam'] = _INDEXPARAM
DESCRIPTOR.message_types_by_name['FlushParam'] = _FLUSHPARAM
DESCRIPTOR.message_types_by_name['DeleteByIDParam'] = _DELETEBYIDPARAM
DESCRIPTOR.message_types_by_name['SegmentStat'] = _SEGMENTSTAT
DESCRIPTOR.message_types_by_name['PartitionStat'] = _PARTITIONSTAT
DESCRIPTOR.message_types_by_name['TableInfo'] = _TABLEINFO
DESCRIPTOR.message_types_by_name['VectorIdentity'] = _VECTORIDENTITY
DESCRIPTOR.message_types_by_name['VectorData'] = _VECTORDATA
DESCRIPTOR.message_types_by_name['GetVectorIDsParam'] = _GETVECTORIDSPARAM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

KeyValuePair = _reflection.GeneratedProtocolMessageType('KeyValuePair', (_message.Message,), {
    'DESCRIPTOR': _KEYVALUEPAIR,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.KeyValuePair)
})
_sym_db.RegisterMessage(KeyValuePair)

TableName = _reflection.GeneratedProtocolMessageType('TableName', (_message.Message,), {
    'DESCRIPTOR': _TABLENAME,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.TableName)
})
_sym_db.RegisterMessage(TableName)

TableNameList = _reflection.GeneratedProtocolMessageType('TableNameList', (_message.Message,), {
    'DESCRIPTOR': _TABLENAMELIST,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.TableNameList)
})
_sym_db.RegisterMessage(TableNameList)

TableSchema = _reflection.GeneratedProtocolMessageType('TableSchema', (_message.Message,), {
    'DESCRIPTOR': _TABLESCHEMA,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.TableSchema)
})
_sym_db.RegisterMessage(TableSchema)

PartitionParam = _reflection.GeneratedProtocolMessageType('PartitionParam', (_message.Message,), {
    'DESCRIPTOR': _PARTITIONPARAM,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.PartitionParam)
})
_sym_db.RegisterMessage(PartitionParam)

PartitionList = _reflection.GeneratedProtocolMessageType('PartitionList', (_message.Message,), {
    'DESCRIPTOR': _PARTITIONLIST,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.PartitionList)
})
_sym_db.RegisterMessage(PartitionList)

RowRecord = _reflection.GeneratedProtocolMessageType('RowRecord', (_message.Message,), {
    'DESCRIPTOR': _ROWRECORD,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.RowRecord)
})
_sym_db.RegisterMessage(RowRecord)

InsertParam = _reflection.GeneratedProtocolMessageType('InsertParam', (_message.Message,), {
    'DESCRIPTOR': _INSERTPARAM,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.InsertParam)
})
_sym_db.RegisterMessage(InsertParam)

VectorIds = _reflection.GeneratedProtocolMessageType('VectorIds', (_message.Message,), {
    'DESCRIPTOR': _VECTORIDS,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.VectorIds)
})
_sym_db.RegisterMessage(VectorIds)

SearchParam = _reflection.GeneratedProtocolMessageType('SearchParam', (_message.Message,), {
    'DESCRIPTOR': _SEARCHPARAM,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.SearchParam)
})
_sym_db.RegisterMessage(SearchParam)

SearchInFilesParam = _reflection.GeneratedProtocolMessageType('SearchInFilesParam', (_message.Message,), {
    'DESCRIPTOR': _SEARCHINFILESPARAM,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.SearchInFilesParam)
})
_sym_db.RegisterMessage(SearchInFilesParam)

SearchByIDParam = _reflection.GeneratedProtocolMessageType('SearchByIDParam', (_message.Message,), {
    'DESCRIPTOR': _SEARCHBYIDPARAM,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.SearchByIDParam)
})
_sym_db.RegisterMessage(SearchByIDParam)

TopKQueryResult = _reflection.GeneratedProtocolMessageType('TopKQueryResult', (_message.Message,), {
    'DESCRIPTOR': _TOPKQUERYRESULT,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.TopKQueryResult)
})
_sym_db.RegisterMessage(TopKQueryResult)

StringReply = _reflection.GeneratedProtocolMessageType('StringReply', (_message.Message,), {
    'DESCRIPTOR': _STRINGREPLY,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.StringReply)
})
_sym_db.RegisterMessage(StringReply)

BoolReply = _reflection.GeneratedProtocolMessageType('BoolReply', (_message.Message,), {
    'DESCRIPTOR': _BOOLREPLY,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.BoolReply)
})
_sym_db.RegisterMessage(BoolReply)

TableRowCount = _reflection.GeneratedProtocolMessageType('TableRowCount', (_message.Message,), {
    'DESCRIPTOR': _TABLEROWCOUNT,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.TableRowCount)
})
_sym_db.RegisterMessage(TableRowCount)

Command = _reflection.GeneratedProtocolMessageType('Command', (_message.Message,), {
    'DESCRIPTOR': _COMMAND,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.Command)
})
_sym_db.RegisterMessage(Command)

IndexParam = _reflection.GeneratedProtocolMessageType('IndexParam', (_message.Message,), {
    'DESCRIPTOR': _INDEXPARAM,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.IndexParam)
})
_sym_db.RegisterMessage(IndexParam)

FlushParam = _reflection.GeneratedProtocolMessageType('FlushParam', (_message.Message,), {
    'DESCRIPTOR': _FLUSHPARAM,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.FlushParam)
})
_sym_db.RegisterMessage(FlushParam)

DeleteByIDParam = _reflection.GeneratedProtocolMessageType('DeleteByIDParam', (_message.Message,), {
    'DESCRIPTOR': _DELETEBYIDPARAM,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.DeleteByIDParam)
})
_sym_db.RegisterMessage(DeleteByIDParam)

SegmentStat = _reflection.GeneratedProtocolMessageType('SegmentStat', (_message.Message,), {
    'DESCRIPTOR': _SEGMENTSTAT,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.SegmentStat)
})
_sym_db.RegisterMessage(SegmentStat)

PartitionStat = _reflection.GeneratedProtocolMessageType('PartitionStat', (_message.Message,), {
    'DESCRIPTOR': _PARTITIONSTAT,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.PartitionStat)
})
_sym_db.RegisterMessage(PartitionStat)

TableInfo = _reflection.GeneratedProtocolMessageType('TableInfo', (_message.Message,), {
    'DESCRIPTOR': _TABLEINFO,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.TableInfo)
})
_sym_db.RegisterMessage(TableInfo)

VectorIdentity = _reflection.GeneratedProtocolMessageType('VectorIdentity', (_message.Message,), {
    'DESCRIPTOR': _VECTORIDENTITY,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.VectorIdentity)
})
_sym_db.RegisterMessage(VectorIdentity)

VectorData = _reflection.GeneratedProtocolMessageType('VectorData', (_message.Message,), {
    'DESCRIPTOR': _VECTORDATA,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.VectorData)
})
_sym_db.RegisterMessage(VectorData)

GetVectorIDsParam = _reflection.GeneratedProtocolMessageType('GetVectorIDsParam', (_message.Message,), {
    'DESCRIPTOR': _GETVECTORIDSPARAM,
    '__module__': 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.grpc.GetVectorIDsParam)
})
_sym_db.RegisterMessage(GetVectorIDsParam)

_MILVUSSERVICE = _descriptor.ServiceDescriptor(
    name='MilvusService',
    full_name='milvus.grpc.MilvusService',
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    serialized_start=2369,
    serialized_end=3980,
    methods=[
        _descriptor.MethodDescriptor(
            name='CreateTable',
            full_name='milvus.grpc.MilvusService.CreateTable',
            index=0,
            containing_service=None,
            input_type=_TABLESCHEMA,
            output_type=status__pb2._STATUS,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='HasTable',
            full_name='milvus.grpc.MilvusService.HasTable',
            index=1,
            containing_service=None,
            input_type=_TABLENAME,
            output_type=_BOOLREPLY,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='DescribeTable',
            full_name='milvus.grpc.MilvusService.DescribeTable',
            index=2,
            containing_service=None,
            input_type=_TABLENAME,
            output_type=_TABLESCHEMA,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='CountTable',
            full_name='milvus.grpc.MilvusService.CountTable',
            index=3,
            containing_service=None,
            input_type=_TABLENAME,
            output_type=_TABLEROWCOUNT,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='ShowTables',
            full_name='milvus.grpc.MilvusService.ShowTables',
            index=4,
            containing_service=None,
            input_type=_COMMAND,
            output_type=_TABLENAMELIST,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='ShowTableInfo',
            full_name='milvus.grpc.MilvusService.ShowTableInfo',
            index=5,
            containing_service=None,
            input_type=_TABLENAME,
            output_type=_TABLEINFO,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='DropTable',
            full_name='milvus.grpc.MilvusService.DropTable',
            index=6,
            containing_service=None,
            input_type=_TABLENAME,
            output_type=status__pb2._STATUS,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='CreateIndex',
            full_name='milvus.grpc.MilvusService.CreateIndex',
            index=7,
            containing_service=None,
            input_type=_INDEXPARAM,
            output_type=status__pb2._STATUS,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='DescribeIndex',
            full_name='milvus.grpc.MilvusService.DescribeIndex',
            index=8,
            containing_service=None,
            input_type=_TABLENAME,
            output_type=_INDEXPARAM,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='DropIndex',
            full_name='milvus.grpc.MilvusService.DropIndex',
            index=9,
            containing_service=None,
            input_type=_TABLENAME,
            output_type=status__pb2._STATUS,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='CreatePartition',
            full_name='milvus.grpc.MilvusService.CreatePartition',
            index=10,
            containing_service=None,
            input_type=_PARTITIONPARAM,
            output_type=status__pb2._STATUS,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='ShowPartitions',
            full_name='milvus.grpc.MilvusService.ShowPartitions',
            index=11,
            containing_service=None,
            input_type=_TABLENAME,
            output_type=_PARTITIONLIST,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='DropPartition',
            full_name='milvus.grpc.MilvusService.DropPartition',
            index=12,
            containing_service=None,
            input_type=_PARTITIONPARAM,
            output_type=status__pb2._STATUS,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='Insert',
            full_name='milvus.grpc.MilvusService.Insert',
            index=13,
            containing_service=None,
            input_type=_INSERTPARAM,
            output_type=_VECTORIDS,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='GetVectorByID',
            full_name='milvus.grpc.MilvusService.GetVectorByID',
            index=14,
            containing_service=None,
            input_type=_VECTORIDENTITY,
            output_type=_VECTORDATA,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='GetVectorIDs',
            full_name='milvus.grpc.MilvusService.GetVectorIDs',
            index=15,
            containing_service=None,
            input_type=_GETVECTORIDSPARAM,
            output_type=_VECTORIDS,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='Search',
            full_name='milvus.grpc.MilvusService.Search',
            index=16,
            containing_service=None,
            input_type=_SEARCHPARAM,
            output_type=_TOPKQUERYRESULT,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='SearchByID',
            full_name='milvus.grpc.MilvusService.SearchByID',
            index=17,
            containing_service=None,
            input_type=_SEARCHBYIDPARAM,
            output_type=_TOPKQUERYRESULT,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='SearchInFiles',
            full_name='milvus.grpc.MilvusService.SearchInFiles',
            index=18,
            containing_service=None,
            input_type=_SEARCHINFILESPARAM,
            output_type=_TOPKQUERYRESULT,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='Cmd',
            full_name='milvus.grpc.MilvusService.Cmd',
            index=19,
            containing_service=None,
            input_type=_COMMAND,
            output_type=_STRINGREPLY,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='DeleteByID',
            full_name='milvus.grpc.MilvusService.DeleteByID',
            index=20,
            containing_service=None,
            input_type=_DELETEBYIDPARAM,
            output_type=status__pb2._STATUS,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='PreloadTable',
            full_name='milvus.grpc.MilvusService.PreloadTable',
            index=21,
            containing_service=None,
            input_type=_TABLENAME,
            output_type=status__pb2._STATUS,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='Flush',
            full_name='milvus.grpc.MilvusService.Flush',
            index=22,
            containing_service=None,
            input_type=_FLUSHPARAM,
            output_type=status__pb2._STATUS,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='Compact',
            full_name='milvus.grpc.MilvusService.Compact',
            index=23,
            containing_service=None,
            input_type=_TABLENAME,
            output_type=status__pb2._STATUS,
            serialized_options=None,
        ),
    ])
_sym_db.RegisterServiceDescriptor(_MILVUSSERVICE)

DESCRIPTOR.services_by_name['MilvusService'] = _MILVUSSERVICE

# @@protoc_insertion_point(module_scope)
